@@ -473,8 +473,8 @@ static gboolean filteringaction_apply(FilteringAction * action, MsgInfo * info)
 			AddressBookFile *abf = NULL;
 			ItemFolder *folder = NULL;
 #endif
-			gchar *buf;
-			Header *header;
+			gchar *buf = NULL;
+			Header *header = NULL;
 			gint errors = 0;
 
 #ifndef USE_ALT_ADDRBOOK
@@ -784,7 +784,6 @@ static gboolean filtering_is_final_action(FilteringAction *filtering_action)
 	case MATCHACTION_MOVE:
 	case MATCHACTION_DELETE:
 	case MATCHACTION_STOP:
-	case MATCHACTION_MARK_AS_SPAM:
 		return TRUE; /* MsgInfo invalid for message */
 	default:
 		return FALSE;
