@@ -31,6 +31,7 @@
 #include "prefs_gtk.h"
 #include "filtering.h"
 #include "folder_item_prefs.h"
+#include "prefs_migration.h"
 
 FolderItemPrefs tmp_prefs;
 
@@ -77,9 +78,13 @@ static PrefParam param[] = {
 	{"default_alt_dictionary", NULL, &tmp_prefs.default_alt_dictionary, P_STRING,
 	 NULL, NULL, NULL},
 #endif	 
+	{"always_sign", "0", &tmp_prefs.always_sign, P_ENUM,
+ 	 NULL, NULL, NULL},
+	{"always_encrypt", "0", &tmp_prefs.always_encrypt, P_ENUM,
+ 	 NULL, NULL, NULL},
 	{"save_copy_to_folder", NULL, &tmp_prefs.save_copy_to_folder, P_BOOL,
 	 NULL, NULL, NULL},
-	{"folder_color", "", &tmp_prefs.color, P_INT,
+	{"folder_color", "#000000", &tmp_prefs.color, P_COLOR,
 	 NULL, NULL, NULL},
 	{"enable_processing", "FALSE", &tmp_prefs.enable_processing, P_BOOL,
 	 NULL, NULL, NULL},
@@ -120,6 +125,8 @@ static PrefParam param[] = {
 	 NULL, NULL, NULL},
 	{"forward_body_format", NULL, &tmp_prefs.forward_body_format, P_STRING,
 	 NULL, NULL, NULL},
+	{"config_version", "-1", &tmp_prefs.config_version, P_INT,
+	 NULL, NULL, NULL},
 	{NULL, NULL, NULL, P_OTHER, NULL, NULL, NULL}
 };
 
@@ -138,6 +145,8 @@ void folder_item_prefs_read_config(FolderItem * item)
 	g_free(rcpath);
 
 	*item->prefs = tmp_prefs;
+
+	prefs_update_config_version_folder_item(item);
 }
 
 void folder_item_prefs_save_config(FolderItem * item)
@@ -198,6 +207,8 @@ static FolderItemPrefs *folder_item_prefs_clear(FolderItemPrefs *prefs)
 	prefs->enable_default_alt_dictionary = FALSE;
 	prefs->default_alt_dictionary = NULL;
 #endif
+	prefs->always_sign = SIGN_OR_ENCRYPT_DEFAULT;
+	prefs->always_encrypt = SIGN_OR_ENCRYPT_DEFAULT;
 	prefs->save_copy_to_folder = FALSE;
 	prefs->color = 0;
 
@@ -305,6 +316,8 @@ void folder_item_prefs_copy_prefs(FolderItem * src, FolderItem * dest)
 	tmp_prefs.enable_default_alt_dictionary	= src->prefs->enable_default_alt_dictionary;
 	tmp_prefs.default_alt_dictionary	= g_strdup(src->prefs->default_alt_dictionary);
 #endif
+	tmp_prefs.always_sign    	= src->prefs->always_sign;
+	tmp_prefs.always_encrypt    = src->prefs->always_encrypt;
 	tmp_prefs.save_copy_to_folder		= src->prefs->save_copy_to_folder;
 	tmp_prefs.color				= src->prefs->color;
 
@@ -323,6 +336,7 @@ void folder_item_prefs_copy_prefs(FolderItem * src, FolderItem * dest)
 
 	*dest->prefs = tmp_prefs;
 	folder_item_prefs_save_config(dest);
+	prefs_matcher_write_config();
 
 	dest->collapsed = src->collapsed;
 	dest->thread_collapsed = src->thread_collapsed;
@@ -333,5 +347,4 @@ void folder_item_prefs_copy_prefs(FolderItem * src, FolderItem * dest)
 	dest->hide_read_threads = src->hide_read_threads;
 	dest->sort_key  = src->sort_key;
 	dest->sort_type = src->sort_type;
-
 }
