@@ -4,7 +4,7 @@ static char *TEAM_LIST[] = {
 "Andrej Kacian <andrej@kacian.sk>",
 "Darko Koruga <darko@users.sf.net>",
 "Charles Lehner <charles@claws-mail.org>",
-"Colin Leroy <colin@colino.net>",
+"Colin Leroy-Mira <colin@colino.net>",
 "Paul Mangan <paul@claws-mail.org>",
 "Ricardo Mones Lastra <ricardo@mones.org>",
 "Salvatore De Paolis <iwkse@claws-mail.org>",
@@ -50,6 +50,7 @@ static char *TRANS_TEAM_LIST[] = {
 "[nl] Marcel Pol <mpol@gmx.net>",
 "[pl] Jakub Jankiewicz <jcubic@jcubic.pl>",
 "[pt_BR] Frederico Goncalves Guimaraes <frederico@teia.bio.br>",
+"[pt_PT] Pedro Albuquerque <palbuquerque73@gmail.com>",
 "[ro] Cristian Secară <liste@secarica.ro>",
 "[ru] Mikhail Kurinnoi <viewizard@viewizard.com>",
 "[sk] Slavko <slavino@slavino.sk>",
@@ -124,6 +125,7 @@ static char *CONTRIBS_LIST[] = {
 "Kevin Day",
 "Matthieu Dazy",
 "Ben Deering",
+"Jean Delvare",
 "Pierric Descamps",
 "Rodrigo Dias Arruda Senra",
 "Frank Dietrich",
@@ -159,6 +161,7 @@ static char *CONTRIBS_LIST[] = {
 "Oliver Haertel",
 "Anders Hammar",
 "Mitko Haralanov",
+"Alexander Lyons Harkness",
 "Hashimoto",
 "Jacob Head",
 "Federico Heinz",
@@ -193,6 +196,7 @@ static char *CONTRIBS_LIST[] = {
 "kazken3",
 "WAKAI Kazunao",
 "Fabian Keil",
+"Jakub Kiciński",
 "Martin Kluge",
 "IWAMOTO Kouichi",
 "Mikhail Kurinnoi",
@@ -282,6 +286,7 @@ static char *CONTRIBS_LIST[] = {
 "shigeri",
 "Jesse Skinner",
 "Ville Skyttä",
+"Alex Smith",
 "Dale P. Smith",
 "Avinash Sonawane",
 "Andrea Spadaccini",
@@ -312,6 +317,7 @@ static char *CONTRIBS_LIST[] = {
 "Jonathan Ware",
 "Watanabe",
 "Rafal Weglarz",
+"Florian Weimer",
 "Martin Wicke",
 "Bob Woodside",
 "YAMAGUCHI",
