@@ -144,6 +144,8 @@ gtk_sctree_get_type (void)
 			sizeof (GtkSCTree),
 			0,	/* n_preallocs */
 			(GInstanceInitFunc) gtk_sctree_init,
+
+			(const GTypeValueTable *) NULL	/* value table */
 		};
 
 		sctree_type = g_type_register_static (GTK_TYPE_CMCTREE, "GtkSCTree", &sctree_info, (GTypeFlags)0);
@@ -431,6 +433,8 @@ sctree_is_hot_spot (GtkSCTree     *sctree,
     return FALSE;
 
   tree_row = GTK_CMCTREE_ROW (node);
+  if (!tree_row->children)
+    return FALSE;
 
   hotspot_size = clist->row_height-2;
   if (hotspot_size > clist->column[ctree->tree_column].area.width - 2)
