@@ -114,6 +114,7 @@ static void import_create(void)
 	gtk_container_set_border_width(GTK_CONTAINER(window), 5);
 	gtk_window_set_position(GTK_WINDOW(window), GTK_WIN_POS_CENTER);
 	gtk_window_set_resizable(GTK_WINDOW(window), TRUE);
+	gtk_window_set_type_hint(GTK_WINDOW(window), GDK_WINDOW_TYPE_HINT_DIALOG);
 	g_signal_connect(G_OBJECT(window), "delete_event",
 			 G_CALLBACK(delete_event), NULL);
 	g_signal_connect(G_OBJECT(window), "key_press_event",
@@ -231,6 +232,14 @@ static void import_ok_cb(GtkWidget *widget, gpointer data)
 		g_free(mbox);
 		return;
 	} else {
+		gtk_widget_set_sensitive(file_entry, FALSE);
+		gtk_widget_set_sensitive(dest_entry, FALSE);
+		gtk_widget_set_sensitive(file_button, FALSE);
+		gtk_widget_set_sensitive(dest_button, FALSE);
+		gtk_widget_set_sensitive(ok_button, FALSE);
+		gtk_widget_set_sensitive(cancel_button, FALSE);
+		GTK_EVENTS_FLUSH();
+
 		import_ok = proc_mbox(dest, mbox, FALSE, NULL);
 	}
 
