@@ -508,8 +508,8 @@ static IncProgressDialog *inc_progress_dialog_create(gboolean autocheck)
 	}
 
 	dialog->dialog = progress;
-	g_get_current_time(&dialog->progress_tv);
-	g_get_current_time(&dialog->folder_tv);
+	dialog->progress_tv = g_date_time_new_now_local();
+	dialog->folder_tv = g_date_time_new_now_local();
 	dialog->queue_list = NULL;
 	dialog->cur_row = 0;
 
@@ -553,6 +553,9 @@ static void inc_progress_dialog_destroy(IncProgressDialog *inc_dialog)
 		main_window_progress_off(inc_dialog->mainwin);
 	progress_dialog_destroy(inc_dialog->dialog);
 
+	g_date_time_unref(inc_dialog->progress_tv);
+	g_date_time_unref(inc_dialog->folder_tv);
+
 	g_free(inc_dialog);
 }
 
@@ -1081,24 +1084,20 @@ static void inc_progress_dialog_set_progress(IncProgressDialog *inc_dialog,
 static void inc_progress_dialog_update_periodic(IncProgressDialog *inc_dialog,
 						IncSession *inc_session)
 {
-	GTimeVal tv_cur;
-	GTimeVal tv_result;
-	gint msec;
+	GDateTime *tv_cur = g_date_time_new_now_local();
+	GTimeSpan tv_result;
 
-	g_get_current_time(&tv_cur);
-
-	tv_result.tv_sec = tv_cur.tv_sec - inc_dialog->progress_tv.tv_sec;
-	tv_result.tv_usec = tv_cur.tv_usec - inc_dialog->progress_tv.tv_usec;
-	if (tv_result.tv_usec < 0) {
-		tv_result.tv_sec--;
-		tv_result.tv_usec += G_USEC_PER_SEC;
+	tv_result = g_date_time_difference(tv_cur, inc_dialog->progress_tv);
+	g_date_time_unref(tv_cur);
+	if (tv_result < 0) {
+	    tv_result += G_USEC_PER_SEC;
 	}
 
-	msec = tv_result.tv_sec * 1000 + tv_result.tv_usec / 1000;
-	if (msec > PROGRESS_UPDATE_INTERVAL) {
-		inc_progress_dialog_update(inc_dialog, inc_session);
-		inc_dialog->progress_tv.tv_sec = tv_cur.tv_sec;
-		inc_dialog->progress_tv.tv_usec = tv_cur.tv_usec;
+	if (tv_result > PROGRESS_UPDATE_INTERVAL) {
+                inc_progress_dialog_update(inc_dialog, inc_session);
+		tv_cur = g_date_time_add(inc_dialog->progress_tv, tv_result);
+		g_date_time_unref(inc_dialog->progress_tv);
+                inc_dialog->progress_tv = tv_cur;
 	}
 }
 
