@@ -63,9 +63,10 @@ typedef enum
 	COL_SIZE     = 1,
 	COL_NAME     = 2,
 	COL_DATA     = 3,
+	N_MIMEVIEW_COLUMNS
 } MimeViewColumnPos;
 
-#define N_MIMEVIEW_COLS	4
+#define N_MIMEVIEW_COLS	(N_MIMEVIEW_COLUMNS)
 
 static void mimeview_set_multipart_tree		(MimeView	*mimeview,
 						 MimeInfo	*mimeinfo,
@@ -1429,6 +1430,14 @@ static void update_signature_info(MimeView *mimeview, MimeInfo *selected)
 	noticeview_show(mimeview->siginfoview);
 }
 
+void mimeview_show_part_as_text(MimeView *mimeview, MimeInfo *partinfo)
+{
+	cm_return_if_fail(mimeview != NULL);
+	cm_return_if_fail(partinfo != NULL);
+
+	mimeview_show_message_part(mimeview, partinfo);
+}
+
 static void mimeview_selected(GtkTreeSelection *selection, MimeView *mimeview)
 {
 	GtkTreeView *ctree = GTK_TREE_VIEW(mimeview->ctree);
@@ -1527,17 +1536,17 @@ static gboolean mimeview_scrolled(GtkWidget *widget, GdkEventScroll *event,
 	return TRUE;
 }
 
-/* from gdkevents.c */
-#define DOUBLE_CLICK_TIME 250
-
 static gboolean part_button_pressed(MimeView *mimeview, GdkEventButton *event, 
 				    MimeInfo *partinfo)
 {
 	static MimeInfo *lastinfo;
 	static guint32 lasttime;
 
+	gint double_click_time;
+	g_object_get(gtk_settings_get_default(), "gtk-double-click-time", &double_click_time, NULL);
+
 	if (event->button == 2 ||
-	    (event->button == 1 && (event->time - lasttime) < DOUBLE_CLICK_TIME && lastinfo == partinfo)) {
+	    (event->button == 1 && (event->time - lasttime) < double_click_time && lastinfo == partinfo)) {
 		/* call external program for image, audio or html */
 		mimeview_launch(mimeview, partinfo);
 		return TRUE;
