@@ -30,7 +30,9 @@
 #include <gdk/gdkkeysyms.h>
 
 /* Claws Mail includes */
+#include <inc.h>
 #include <mainwindow.h>
+#include <prefs_common.h>
 #include <prefs_gtk.h>
 
 /* Local includes */
@@ -194,6 +196,15 @@ rssyl_props_trim_cb(GtkWidget *widget, gpointer data)
 	RFolderItem *ritem = (RFolderItem *)data;
 	gboolean k = ritem->keep_old;
 
+	if( prefs_common_get_prefs()->work_offline &&
+			!inc_offline_should_override(TRUE,
+					ngettext("Claws Mail needs network access in order "
+					"to update the feed.",
+					"Claws Mail needs network access in order "
+					"to update feeds.", 1))) {
+		return FALSE;
+	}
+
 	if( k )
 		ritem->keep_old = FALSE;
 
@@ -211,11 +222,11 @@ rssyl_props_key_press_cb(GtkWidget *widget, GdkEventKey *event,
 {
 	if (event) {
 		switch (event->keyval) {
-			case GDK_Escape:
+			case GDK_KEY_Escape:
 				rssyl_props_cancel_cb(widget, data);
 				return TRUE;
-			case GDK_Return:
-			case GDK_KP_Enter:
+			case GDK_KEY_Return:
+			case GDK_KEY_KP_Enter:
 				rssyl_props_ok_cb(widget, data);
 				return TRUE;
 			default:
@@ -252,19 +263,10 @@ void rssyl_gtk_prop(RFolderItem *ritem)
 	gtk_entry_set_text(GTK_ENTRY(feedprop->url), ritem->url);
 
 	/* URL auth type combo */
-#if !GTK_CHECK_VERSION(2, 24, 0)
-	feedprop->auth_type = gtk_combo_box_new_text();
-	gtk_combo_box_append_text(GTK_COMBO_BOX(feedprop->auth_type),
-#else
 	feedprop->auth_type = gtk_combo_box_text_new();
 	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(feedprop->auth_type),
-#endif
 			_("No authentication"));
-#if !GTK_CHECK_VERSION(2, 24, 0)
-	gtk_combo_box_append_text(GTK_COMBO_BOX(feedprop->auth_type),
-#else
 	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(feedprop->auth_type),
-#endif
 			_("HTTP Basic authentication"));
 	gtk_combo_box_set_active(GTK_COMBO_BOX(feedprop->auth_type),
 			ritem->auth->type);
@@ -272,13 +274,14 @@ void rssyl_gtk_prop(RFolderItem *ritem)
 	/* Auth username */
 	feedprop->auth_username = gtk_entry_new();
 	gtk_entry_set_text(GTK_ENTRY(feedprop->auth_username),
-			ritem->auth->username);
+			(ritem->auth->username != NULL ? ritem->auth->username : ""));
 
 	/* Auth password */
 	feedprop->auth_password = gtk_entry_new();
 	gtk_entry_set_visibility(GTK_ENTRY(feedprop->auth_password), FALSE);
 	gchar *pwd = rssyl_passwd_get(ritem);
-	gtk_entry_set_text(GTK_ENTRY(feedprop->auth_password), pwd);
+	gtk_entry_set_text(GTK_ENTRY(feedprop->auth_password),
+			(pwd != NULL ? pwd : ""));
 	if (pwd != NULL) {
 		memset(pwd, 0, strlen(pwd));
 		g_free(pwd);
@@ -327,25 +330,12 @@ void rssyl_gtk_prop(RFolderItem *ritem)
 			1, 0);
 
 	/* Silent update - combobox */
-#if !GTK_CHECK_VERSION(2, 24, 0)
-	feedprop->silent_update = gtk_combo_box_new_text();
-	gtk_combo_box_append_text(GTK_COMBO_BOX(feedprop->silent_update),
-#else
 	feedprop->silent_update = gtk_combo_box_text_new();
 	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(feedprop->silent_update),
-#endif
 			_("Always mark it as new"));
-#if !GTK_CHECK_VERSION(2, 24, 0)
-	gtk_combo_box_append_text(GTK_COMBO_BOX(feedprop->silent_update),
-#else
 	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(feedprop->silent_update),
-#endif
 			_("Only mark it as new if its text has changed"));
-#if !GTK_CHECK_VERSION(2, 24, 0)
-	gtk_combo_box_append_text(GTK_COMBO_BOX(feedprop->silent_update),
-#else
 	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(feedprop->silent_update),
-#endif
 			_("Never mark it as new"));
 	gtk_combo_box_set_active(GTK_COMBO_BOX(feedprop->silent_update),
 			ritem->silent_update);
@@ -512,7 +502,7 @@ void rssyl_gtk_prop(RFolderItem *ritem)
 	/* OK button */
 	ok_button = gtk_button_new();
 	gtk_container_add(GTK_CONTAINER(bbox), ok_button);
-	GTK_WIDGET_SET_FLAGS(ok_button, GTK_CAN_DEFAULT );
+	gtk_widget_set_can_default(ok_button, TRUE);
 
 	ok_align = gtk_alignment_new(0.5, 0.5, 0, 0);
 	gtk_container_add(GTK_CONTAINER(ok_button), ok_align);
