@@ -41,7 +41,7 @@
 gint plugin_init(gchar **error)
 {
 	if (!check_plugin_version(MAKE_NUMERIC_VERSION(3,13,2,39),
-				VERSION_NUMERIC, _("vCalendar"), error))
+				VERSION_NUMERIC, PLUGIN_NAME, error))
 		return -1;
 
 	tzset();
@@ -65,7 +65,7 @@ gboolean plugin_done(void)
 
 const gchar *plugin_name(void)
 {
-	return _("vCalendar");
+	return _(PLUGIN_NAME);
 }
 
 const gchar *plugin_desc(void)
@@ -79,7 +79,7 @@ const gchar *plugin_desc(void)
 		 "appropriate form and you will be able to accept or decline them.\n"
 		 "To create a meeting right-click on the vCalendar or "
 		 "Meetings folder and choose \"New meeting...\".\n\n"
-		 "You will also be able to subscribe to remote Webcal feeds,"
+		 "You will also be able to subscribe to remote Webcal feeds, "
 		 "export your meetings and calendars, publish your free/busy "
 		 "information and retrieve that information from others.");
 }
