@@ -1,6 +1,6 @@
 /*
  * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2016 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 1999-2019 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -1017,6 +1017,8 @@ static PrefParam param[] = {
 
 	{"gtk_can_change_accels", "FALSE", &prefs_common.gtk_can_change_accels, P_BOOL,
 	 NULL, NULL, NULL},
+	{"gtk_enable_accels", "TRUE", &prefs_common.gtk_enable_accels, P_BOOL,
+	 NULL, NULL, NULL},
 
 	{"color_new", "#0000b3", &prefs_common.color[COL_NEW],
 	 P_COLOR, NULL, NULL, NULL},
@@ -1062,6 +1064,16 @@ static PrefParam param[] = {
 	{"sslmanwin_height", "-1", &prefs_common.sslmanwin_height, P_INT,
 	 NULL, NULL, NULL},
 
+	{"uriopenerwin_width", "-1", &prefs_common.uriopenerwin_width, P_INT,
+	 NULL, NULL, NULL},
+	{"uriopenerwin_height", "-1", &prefs_common.uriopenerwin_height, P_INT,
+	 NULL, NULL, NULL},
+
+	{"foldersortwin_width", "400", &prefs_common.foldersortwin_width, P_INT,
+	 NULL, NULL, NULL},
+	{"foldersortwin_height", "300", &prefs_common.foldersortwin_height, P_INT,
+	 NULL, NULL, NULL},
+
 	{"addressbookwin_width", "520", &prefs_common.addressbookwin_width, P_INT,
 	 NULL, NULL, NULL},
 	{"addressbookwin_height", "-1", &prefs_common.addressbookwin_height, P_INT,
