@@ -718,7 +718,6 @@ static void textview_add_part(TextView *textview, MimeInfo *mimeinfo)
 			GdkPixbuf *pixbuf;
 			GError *error = NULL;
 			ClickableText *uri;
-			GInputStream *stream;
 
 			START_TIMING("inserting image");
 
@@ -1037,10 +1036,11 @@ static void textview_write_body(TextView *textview, MimeInfo *mimeinfo)
 	textview->is_in_signature = FALSE;
 	textview->is_diff = FALSE;
 	textview->is_attachment = FALSE;;
+	textview->is_in_git_patch = FALSE;
 
 	procmime_decode_content(mimeinfo);
 
-	account_signatures_matchlist_create();
+	account_sigsep_matchlist_create();
 
 	if (!g_ascii_strcasecmp(mimeinfo->subtype, "html") &&
 	    prefs_common.render_html) {
@@ -1123,7 +1123,7 @@ static void textview_write_body(TextView *textview, MimeInfo *mimeinfo)
 				claws_fclose(tmpfp);
 				waitpid(pid, pfd, 0);
 				g_unlink(fname);
-				account_signatures_matchlist_delete();
+				account_sigsep_matchlist_delete();
 				return;
 			}
 		}
@@ -1153,13 +1153,13 @@ textview_default:
 			tmpfp = claws_fopen(mimeinfo->data.filename, "rb");
 		if (!tmpfp) {
 			FILE_OP_ERROR(mimeinfo->data.filename, "claws_fopen");
-			account_signatures_matchlist_delete();
+			account_sigsep_matchlist_delete();
 			return;
 		}
 		if (fseek(tmpfp, mimeinfo->offset, SEEK_SET) < 0) {
 			FILE_OP_ERROR(mimeinfo->data.filename, "fseek");
 			claws_fclose(tmpfp);
-			account_signatures_matchlist_delete();
+			account_sigsep_matchlist_delete();
 			return;
 		}
 		debug_print("Viewing text content of type: %s (length: %d)\n", mimeinfo->subtype, mimeinfo->length);
@@ -1169,7 +1169,7 @@ textview_default:
 			textview_write_line(textview, buf, conv, TRUE);
 			if (textview->stop_loading) {
 				claws_fclose(tmpfp);
-				account_signatures_matchlist_delete();
+				account_sigsep_matchlist_delete();
 				return;
 			}
 			wrote += ftell(tmpfp)-i;
@@ -1182,7 +1182,7 @@ textview_default:
 		claws_fclose(tmpfp);
 	}
 
-	account_signatures_matchlist_delete();
+	account_sigsep_matchlist_delete();
 
 	conv_code_converter_destroy(conv);
 	procmime_force_encoding(0);
@@ -1220,7 +1220,7 @@ static void textview_show_html(TextView *textview, FILE *fp,
 	parser = sc_html_parser_new(fp, conv);
 	cm_return_if_fail(parser != NULL);
 
-	account_signatures_matchlist_create();
+	account_sigsep_matchlist_create();
 
 	while ((str = sc_html_parse(parser)) != NULL) {
 	        if (parser->state == SC_HTML_HREF) {
@@ -1246,13 +1246,13 @@ static void textview_show_html(TextView *textview, FILE *fp,
 		if (lines % 500 == 0)
 			GTK_EVENTS_FLUSH();
 		if (textview->stop_loading) {
-			account_signatures_matchlist_delete();
+			account_sigsep_matchlist_delete();
 			return;
 		}
 	}
 	textview_write_line(textview, "\n", NULL, FALSE);
 
-	account_signatures_matchlist_delete();
+	account_sigsep_matchlist_delete();
 
 	sc_html_parser_destroy(parser);
 }
@@ -1267,7 +1267,7 @@ static void textview_show_ertf(TextView *textview, FILE *fp,
 	parser = ertf_parser_new(fp, conv);
 	cm_return_if_fail(parser != NULL);
 
-	account_signatures_matchlist_create();
+	account_sigsep_matchlist_create();
 
 	while ((str = ertf_parse(parser)) != NULL) {
 		textview_write_line(textview, str, NULL, FALSE);
@@ -1275,12 +1275,12 @@ static void textview_show_ertf(TextView *textview, FILE *fp,
 		if (lines % 500 == 0)
 			GTK_EVENTS_FLUSH();
 		if (textview->stop_loading) {
-			account_signatures_matchlist_delete();
+			account_sigsep_matchlist_delete();
 			return;
 		}
 	}
 	
-	account_signatures_matchlist_delete();
+	account_sigsep_matchlist_delete();
 
 	ertf_parser_destroy(parser);
 }
@@ -1610,7 +1610,7 @@ static void textview_write_line(TextView *textview, const gchar *str,
 	}
 
 	if (prefs_common.enable_color) {
-		if (textview->is_diff) {
+		if (textview->is_diff || textview->is_in_git_patch) {
 			if (strncmp(buf, "+++ ", 4) == 0)
 				fg_color = "diff-add-file";
 			else if (buf[0] == '+')
@@ -1620,13 +1620,21 @@ static void textview_write_line(TextView *textview, const gchar *str,
 			else if (buf[0] == '-')
 				fg_color = "diff-del";
 			else if (strncmp(buf, "@@ ", 3) == 0 &&
-					strcmp(buf+strlen(buf)-4, " @@\n") == 0)
+				 strstr(&buf[3], " @@"))
 				fg_color = "diff-hunk";
-		} else if (account_signatures_matchlist_str_found(buf,"%s\n")
-				|| account_signatures_matchlist_str_found(buf, "- %s\n")
+
+			if (account_sigsep_matchlist_nchar_found(buf, "%s\n")) {
+				textview->is_in_git_patch = FALSE;
+				textview->is_in_signature = TRUE;
+				fg_color = "signature";
+			}
+		} else if (account_sigsep_matchlist_str_found(buf, "%s\n")
+				|| account_sigsep_matchlist_str_found(buf, "- %s\n")
 				|| textview->is_in_signature) {
 			fg_color = "signature";
 			textview->is_in_signature = TRUE;
+		} else if (strncmp(buf, "diff --git ", 11) == 0) {
+			textview->is_in_git_patch = TRUE;
 		}
 	}
 
